.. -*- mode: rst -*-

People
------

This work is made available by a community of people, which
originated from
the `INRIA Parietal Project Team <https://team.inria.fr/parietal/>`_
and the `scikit-learn <http://scikit-learn.org/>`_ but grew much further.

An up-to-date list of contributors can be seen in on `gitub
<https://github.com/nilearn/nilearn/graphs/contributors>`_

Additional credit goes to M. Hanke and Y. Halchenko for data and packaging.

.. _core_devs:

Core developers
.................

The nilearn core developers are:

* Alexandre Gramfort https://github.com/agramfort
* Ben Cipollini https://github.com/bcipolli
* Bertrand Thirion https://github.com/bthirion
* Chris Gorgolewski https://github.com/chrisgorgo
* Danilo Bzdok https://github.com/banilo
* Elizabeth DuPre https://github.com/emdupre
* Gael Varoquaux https://github.com/GaelVaroquaux
* Jerome Dockes https://github.com/jeromedockes
* Julia Huntenburg https://github.com/juhuntenburg
* KamalakerDadi https://github.com/KamalakerDadi
* Kshitij Chawla https://github.com/kchawla-pi
* Medhi Rahim https://github.com/mrahim
* Salma Bougacha https://github.com/salma1601

Funding
........

Alexandre Abraham, Gael Varoquaux, Kamalakar Reddy Daddy, Loïc Estève,
Mehdi Rahim, Philippe Gervais where payed by the `NiConnect
<https://team.inria.fr/parietal/18-2/spatial_patterns/niconnect>`_
project, funded by the French `Investissement d'Avenir
<http://www.gouvernement.fr/investissements-d-avenir-cgi>`_.

NiLearn is also supported by `DigiCosme <https://digicosme.lri.fr>`_
|digicosme logo| and `DataIA <https://dataia.eu/en>`_ |dataia_logo|.

.. _citing:

Citing nilearn
------------------------

There is no paper published yet about nilearn. We are waiting for the
package to mature a bit. However, the patterns underlying the package
have been described in: `Machine learning for neuroimaging with
scikit-learn
<http://journal.frontiersin.org/article/10.3389/fninf.2014.00014/abstract>`_.

We suggest that you read and cite the paper. Thank you.


Citing scikit-learn
------------------------

A huge amount of work goes in the scikit-learn. Researchers that invest
their time in developing and maintaining the package deserve recognition
with citations. In addition, the Parietal team needs the citations to the
paper in order to justify paying a software engineer on the project. To
guarantee the future of the toolkit, if you use it, please cite it.

See the scikit-learn documentation on `how to cite
<http://scikit-learn.org/stable/about.html#citing-scikit-learn>`_.


.. |digicosme logo| image:: logos/digi-saclay-logo-small.png
    :height: 25
    :alt: DigiComse Logo

.. |dataia_logo| image:: logos/dataia.png
    :height: 25
    :alt: DataIA Logo
